#ifndef EL__ECMASCRIPT_MUJS_NAVIGATOR_H
#define EL__ECMASCRIPT_MUJS_NAVIGATOR_H

#include <mujs.h>

#ifdef __cplusplus
extern "C" {
#endif

int mjs_navigator_init(js_State *J);

#ifdef __cplusplus
}
#endif

#endif
